@@ -1,25 +1,33 @@
 /****************************************************************************
-*                   blob.h
-*
-*  This module contains all defines, typedefs, and prototypes for BLOB.C.
-*
-*  from Persistence of Vision(tm) Ray Tracer
-*  Copyright 1996 Persistence of Vision Team
-*---------------------------------------------------------------------------
-*  NOTICE: This source code file is provided so that users may experiment
-*  with enhancements to POV-Ray and to port the software to platforms other
-*  than those supported by the POV-Ray Team.  There are strict rules under
-*  which you are permitted to use this file.  The rules are in the file
-*  named POVLEGAL.DOC which should be distributed with this file. If
-*  POVLEGAL.DOC is not available or for more info please contact the POV-Ray
-*  Team Coordinator by leaving a message in CompuServe's Graphics Developer's
-*  Forum.  The latest version of POV-Ray may be found there as well.
-*
-* This program is based on the popular DKB raytracer version 2.12.
-* DKBTrace was originally written by David K. Buck.
-* DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
-*
-*****************************************************************************/
+ *                  blob.h
+ *
+ * This module contains all defines, typedefs, and prototypes for BLOB.CPP.
+ *
+ * from Persistence of Vision(tm) Ray Tracer version 3.6.
+ * Copyright 1991-2003 Persistence of Vision Team
+ * Copyright 2003-2004 Persistence of Vision Raytracer Pty. Ltd.
+ *---------------------------------------------------------------------------
+ * NOTICE: This source code file is provided so that users may experiment
+ * with enhancements to POV-Ray and to port the software to platforms other
+ * than those supported by the POV-Ray developers. There are strict rules
+ * regarding how you are permitted to use this file. These rules are contained
+ * in the distribution and derivative versions licenses which should have been
+ * provided with this file.
+ *
+ * These licences may be found online, linked from the end-user license
+ * agreement that is located at http://www.povray.org/povlegal.html
+ *---------------------------------------------------------------------------
+ * This program is based on the popular DKB raytracer version 2.12.
+ * DKBTrace was originally written by David K. Buck.
+ * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
+ *---------------------------------------------------------------------------
+ * $File: //depot/povray/3.6-release/source/blob.h $
+ * $Revision: #2 $
+ * $Change: 2939 $
+ * $DateTime: 2004/07/04 13:43:26 $
+ * $Author: root $
+ * $Log$
+ *****************************************************************************/
 
 
 #ifndef BLOB_H
@@ -27,7 +35,7 @@
 
 #include "bsphere.h"
 
-
+BEGIN_POV_NAMESPACE
 
 /*****************************************************************************
 * Global preprocessor defines
@@ -92,9 +100,10 @@ struct Blob_Data_Struct
 struct Blob_Struct
 {
   OBJECT_FIELDS
-  TRANSFORM *Trans;
   BLOB_DATA *Data;    /* Pointer to blob data  */
   TEXTURE **Element_Texture;
+  BSPHERE_TREE **Queue;
+  unsigned int Max_Queue_Size;
 };
 
 struct Blob_List_Struct
@@ -124,23 +133,19 @@ extern METHODS Blob_Methods;
 * Global functions
 ******************************************************************************/
 
-void Set_Blob_Solver PARAMS((OBJECT *obj, int Sturm_Flag));
-void Init_Blob_Queue PARAMS((void));
-void BlobDelete PARAMS((OBJECT *obj));
-BLOB *Create_Blob PARAMS((void));
-void Make_Blob PARAMS((BLOB *blob, DBL threshold, BLOB_LIST *bloblist, int npoints));
-BLOB_LIST *Create_Blob_List_Element PARAMS((void));
-void Create_Blob_Element_Texture_List PARAMS((BLOB *Blob, BLOB_LIST *BlobList, int npoints));
-void Determine_Blob_Textures PARAMS((BLOB *Blob, VECTOR P, int *Count, TEXTURE **Textures, DBL *Weights));
-void Test_Blob_Opacity PARAMS((BLOB *Blob));
-
-void Translate_Blob_Element PARAMS((BLOB_ELEMENT *Element, VECTOR Vector));
-void Rotate_Blob_Element PARAMS((BLOB_ELEMENT *Element, VECTOR Vector));
-void Scale_Blob_Element PARAMS((BLOB_ELEMENT *Element, VECTOR Vector));
-void Invert_Blob_Element PARAMS((BLOB_ELEMENT *Element));
-void Transform_Blob_Element PARAMS((BLOB_ELEMENT *Element, TRANSFORM *Trans));
-void Destroy_Blob_Queue PARAMS((void));
+BLOB *Create_Blob (void);
+void Make_Blob (BLOB *blob, DBL threshold, BLOB_LIST *bloblist, int npoints);
+BLOB_LIST *Create_Blob_List_Element (void);
+void Create_Blob_Element_Texture_List (BLOB *Blob, BLOB_LIST *BlobList, int npoints);
+void Determine_Blob_Textures (BLOB *Blob, VECTOR P, int *Count, TEXTURE **Textures, DBL *Weights);
+void Test_Blob_Opacity (BLOB *Blob);
 
+void Translate_Blob_Element (BLOB_ELEMENT *Element, VECTOR Vector);
+void Rotate_Blob_Element (BLOB_ELEMENT *Element, VECTOR Vector);
+void Scale_Blob_Element (BLOB_ELEMENT *Element, VECTOR Vector);
+void Invert_Blob_Element (BLOB_ELEMENT *Element);
+void Transform_Blob_Element (BLOB_ELEMENT *Element, TRANSFORM *Trans);
 
+END_POV_NAMESPACE
 
 #endif
