@@ -25,10 +25,10 @@
  * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
  *---------------------------------------------------------------------------
  * $File: //depot/povray/3.6-release/source/fpmetric.cpp $
- * $Revision: #2 $
- * $Change: 2939 $
- * $DateTime: 2004/07/04 13:43:26 $
- * $Author: root $
+ * $Revision: #3 $
+ * $Change: 3032 $
+ * $DateTime: 2004/08/02 18:43:41 $
+ * $Author: chrisc $
  * $Log$
  *****************************************************************************/
 
@@ -40,7 +40,6 @@
 #include "objects.h"
 #include "boxes.h"
 #include "spheres.h"
-#include "povproto.h"
 #include "vector.h"
 #include "matrices.h"
 #include "bbox.h"
