@@ -24,20 +24,19 @@
  * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
  *---------------------------------------------------------------------------
  * $File: //depot/povray/3.6-release/source/photons.cpp $
- * $Revision: #2 $
- * $Change: 2939 $
- * $DateTime: 2004/07/04 13:43:26 $
- * $Author: root $
+ * $Revision: #3 $
+ * $Change: 3032 $
+ * $DateTime: 2004/08/02 18:43:41 $
+ * $Author: chrisc $
  * $Log$
  *****************************************************************************/
 
 
 #include "frame.h"
+#include "userio.h"
 #include "povray.h"
 #include "vector.h"
-#include "povproto.h"
 #include "texture.h"  /* for FRAND() */
-#include "povproto.h"    /* for Warning() */
 #include "matrices.h"
 #include "objects.h"
 #include "csg.h"
