@@ -1,25 +1,33 @@
 /****************************************************************************
-*                   povray.h
-*
-*  This module contains all defines, typedefs, and prototypes for POVRAY.C.
-*
-*  from Persistence of Vision(tm) Ray Tracer
-*  Copyright 1996 Persistence of Vision Team
-*---------------------------------------------------------------------------
-*  NOTICE: This source code file is provided so that users may experiment
-*  with enhancements to POV-Ray and to port the software to platforms other
-*  than those supported by the POV-Ray Team.  There are strict rules under
-*  which you are permitted to use this file.  The rules are in the file
-*  named POVLEGAL.DOC which should be distributed with this file. If
-*  POVLEGAL.DOC is not available or for more info please contact the POV-Ray
-*  Team Coordinator by leaving a message in CompuServe's Graphics Developer's
-*  Forum.  The latest version of POV-Ray may be found there as well.
-*
-* This program is based on the popular DKB raytracer version 2.12.
-* DKBTrace was originally written by David K. Buck.
-* DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
-*
-*****************************************************************************/
+ *                  povray.h
+ *
+ * This module contains all defines, typedefs, and prototypes for POVRAY.CPP.
+ *
+ * from Persistence of Vision(tm) Ray Tracer version 3.6.
+ * Copyright 1991-2003 Persistence of Vision Team
+ * Copyright 2003-2004 Persistence of Vision Raytracer Pty. Ltd.
+ *---------------------------------------------------------------------------
+ * NOTICE: This source code file is provided so that users may experiment
+ * with enhancements to POV-Ray and to port the software to platforms other
+ * than those supported by the POV-Ray developers. There are strict rules
+ * regarding how you are permitted to use this file. These rules are contained
+ * in the distribution and derivative versions licenses which should have been
+ * provided with this file.
+ *
+ * These licences may be found online, linked from the end-user license
+ * agreement that is located at http://www.povray.org/povlegal.html
+ *---------------------------------------------------------------------------
+ * This program is based on the popular DKB raytracer version 2.12.
+ * DKBTrace was originally written by David K. Buck.
+ * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
+ *---------------------------------------------------------------------------
+ * $File: //depot/povray/3.6-release/source/povray.h $
+ * $Revision: #2 $
+ * $Change: 2939 $
+ * $DateTime: 2004/07/04 13:43:26 $
+ * $Author: root $
+ * $Log$
+ *****************************************************************************/
 
 
 #ifndef POVRAY_H
@@ -27,11 +35,19 @@
 
 #include <time.h>
 
+#include "frame.h"
 #include "atmosph.h"
 #include "camera.h"
+#include "media.h"
 #include "point.h"
 #include "render.h"
+#include "userio.h"
+#include "povms.h"
+#include "lightgrp.h"
 
+BEGIN_POV_NAMESPACE
+
+USING_POV_BASE_NAMESPACE
 
 /*****************************************************************************
 * Global preprocessor defines
@@ -39,22 +55,21 @@
 
 #define MAX_LIBRARIES 25
 
-#define STAGE_STARTUP         0  /* set in POVRAY.C */
-#define STAGE_BANNER          1  /* set in POVRAY.C */
-#define STAGE_INIT            2  /* set in POVRAY.C */
-#define STAGE_ENVIRONMENT     3  /* set in POVRAY.C */
-#define STAGE_COMMAND_LINE    4  /* set in POVRAY.C */
-#define STAGE_FILE_INIT       5  /* set in POVRAY.C */
-#define STAGE_PARSING         7  /* set in PARSE.C */
-#define STAGE_CONTINUING      8  /* set in POVRAY.C */
-#define STAGE_RENDERING       9  /* set in POVRAY.C */
-#define STAGE_SHUTDOWN       10  /* set in POVRAY.C */
-#define STAGE_INI_FILE       11  /* set in POVRAY.C */
-#define STAGE_CLEANUP_PARSE  12  /* set in PARSE.C */
-#define STAGE_SLAB_BUILDING  13  /* set in POVRAY.C */
-#define STAGE_TOKEN_INIT     14  /* set in TOKENIZE.C */
-#define STAGE_INCLUDE_ERR    15  /* set in TOKENIZE.C */
-#define STAGE_FOUND_INSTEAD  16  /* set in TOKENIZE.C */
+#define STAGE_PREINIT         0  /* set in POVRAY.C */
+#define STAGE_STARTUP         1  /* set in POVRAY.C */
+#define STAGE_BANNER          2  /* set in POVRAY.C */
+#define STAGE_INIT            3  /* set in POVRAY.C */
+#define STAGE_FILE_INIT       4  /* set in POVRAY.C */
+#define STAGE_PARSING         5  /* set in PARSE.C */
+#define STAGE_CONTINUING      6  /* set in POVRAY.C */
+#define STAGE_RENDERING       7  /* set in POVRAY.C */
+#define STAGE_SHUTDOWN        8  /* set in POVRAY.C */
+#define STAGE_CLEANUP_PARSE   9  /* set in PARSE.C */
+#define STAGE_SLAB_BUILDING  10  /* set in POVRAY.C */
+#define STAGE_TOKEN_INIT     11  /* set in TOKENIZE.C */
+#define STAGE_INCLUDE_ERR    12  /* set in TOKENIZE.C */
+#define STAGE_FOUND_INSTEAD  13  /* set in TOKENIZE.C */
+#define STAGECOUNT           14  /* number of stages */
 
 #define DISPLAY           0x000001L
 #define VERBOSE           0x000002L
@@ -64,21 +79,19 @@
 #define RGBSEPARATE       0x000020L
 #define EXITENABLE        0x000040L
 #define CONTINUE_TRACE    0x000080L
-#define BUFFERED_OUTPUT   0x000100L
-#define JITTER            0x000200L
-#define PREVIEW           0x000400L
-#define SPLIT_UNION       0x000800L
-#define USE_VISTA_BUFFER  0x001000L
-#define USE_LIGHT_BUFFER  0x002000L
-#define USE_VISTA_DRAW    0x004000L
-#define REMOVE_BOUNDS     0x008000L
-#define CYCLIC_ANIMATION  0x010000L
-#define OUTPUT_ALPHA      0x020000L
-#define HF_GRAY_16        0x040000L
-#define GAMMA_CORRECT     0x080000L
-#define RADIOSITY         0x100000L
-#define FROM_STDIN        0x200000L
-#define TO_STDOUT         0x400000L
+#define JITTER            0x000100L
+#define PREVIEW           0x000200L
+#define SPLIT_UNION       0x000400L
+#define USE_VISTA_BUFFER  0x000800L
+#define USE_LIGHT_BUFFER  0x001000L
+#define USE_VISTA_DRAW    0x002000L
+#define REMOVE_BOUNDS     0x004000L
+#define CYCLIC_ANIMATION  0x008000L
+#define OUTPUT_ALPHA      0x010000L
+#define HF_GRAY_16        0x020000L
+#define GAMMA_CORRECT     0x040000L
+#define FROM_STDIN        0x080000L
+#define TO_STDOUT         0x100000L
 
 #define Q_FULL_AMBIENT 0x000001L
 #define Q_QUICKC       0x000002L
@@ -90,8 +103,10 @@
 #define Q_VOLUME       0x000080L
 
 #define EF_RADIOS  1
-#define EF_HALOS   2
-#define EF_ATMOS   4
+#define EF_SLOPEM  2
+#define EF_ISOFN   4
+#define EF_SPLINE  8
+#define EF_TIFF    16
 
 #define QUALITY_0  Q_QUICKC+Q_FULL_AMBIENT
 #define QUALITY_1  QUALITY_0
@@ -118,14 +133,16 @@ struct Frame_Struct
   int Number_Of_Light_Sources;
   LIGHT_SOURCE *Light_Sources;
   OBJECT *Objects;
-  DBL Atmosphere_IOR, Antialias_Threshold;
+  DBL Atmosphere_IOR, Atmosphere_Dispersion, Antialias_Threshold;
   COLOUR Background_Colour;
   COLOUR Ambient_Light;
   COLOUR Irid_Wavelengths;
-  ATMOSPHERE *Atmosphere;
+  IMEDIA *Atmosphere;
   FOG *Fog;
   RAINBOW *Rainbow;
   SKYSPHERE *Skysphere;
+  LIGHT_GROUP_LIGHT *Light_Group_Lights;  // Maintain a separate, independent list of all lights
+                                          // that are part of light groups.
 };
 
 typedef enum STATS
@@ -139,13 +156,12 @@ typedef enum STATS
   Calls_To_Noise,
   ADC_Saves,
 
-  /* objects */
-  Bounding_Region_Tests,
-  Bounding_Region_Tests_Succeeded,
-  Clipping_Region_Tests,
-  Clipping_Region_Tests_Succeeded,
+  /* intersecion stack */
   Istack_overflows,
 
+  /* objects */
+  Ray_RBezier_Tests,
+  Ray_RBezier_Tests_Succeeded,
   Ray_Bicubic_Tests,
   Ray_Bicubic_Tests_Succeeded,
   Ray_Blob_Tests,
@@ -158,8 +174,16 @@ typedef enum STATS
   Ray_Box_Tests_Succeeded,
   Ray_Cone_Tests,
   Ray_Cone_Tests_Succeeded,
+  Ray_CSG_Intersection_Tests,
+  Ray_CSG_Intersection_Tests_Succeeded,
+  Ray_CSG_Merge_Tests,
+  Ray_CSG_Merge_Tests_Succeeded,
+  Ray_CSG_Union_Tests,
+  Ray_CSG_Union_Tests_Succeeded,
   Ray_Disc_Tests,
   Ray_Disc_Tests_Succeeded,
+  Ray_Fractal_Tests,
+  Ray_Fractal_Tests_Succeeded,
   Ray_HField_Tests,
   Ray_HField_Tests_Succeeded,
   Ray_HField_Box_Tests,
@@ -170,8 +194,12 @@ typedef enum STATS
   Ray_HField_Block_Tests_Succeeded,
   Ray_HField_Cell_Tests,
   Ray_HField_Cell_Tests_Succeeded,
-  Ray_Fractal_Tests,
-  Ray_Fractal_Tests_Succeeded,
+  Ray_IsoSurface_Tests,
+  Ray_IsoSurface_Tests_Succeeded,
+  Ray_IsoSurface_Bound_Tests,
+  Ray_IsoSurface_Bound_Tests_Succeeded,
+  Ray_IsoSurface_Cache,
+  Ray_IsoSurface_Cache_Succeeded,
   Ray_Lathe_Tests,
   Ray_Lathe_Tests_Succeeded,
   Lathe_Bound_Tests,
@@ -180,44 +208,65 @@ typedef enum STATS
   Ray_Mesh_Tests_Succeeded,
   Ray_Plane_Tests,
   Ray_Plane_Tests_Succeeded,
-  Ray_Poly_Tests,
-  Ray_Poly_Tests_Succeeded,
   Ray_Polygon_Tests,
   Ray_Polygon_Tests_Succeeded,
   Ray_Prism_Tests,
   Ray_Prism_Tests_Succeeded,
   Prism_Bound_Tests,
   Prism_Bound_Tests_Succeeded,
+  Ray_Parametric_Tests,
+  Ray_Parametric_Tests_Succeeded,
+  Ray_Par_Bound_Tests,
+  Ray_Par_Bound_Tests_Succeeded,
   Ray_Quadric_Tests,
   Ray_Quadric_Tests_Succeeded,
+  Ray_Poly_Tests,
+  Ray_Poly_Tests_Succeeded,
+  Ray_Sphere_Tests,
+  Ray_Sphere_Tests_Succeeded,
+  Ray_Sphere_Sweep_Tests,
+  Ray_Sphere_Sweep_Tests_Succeeded,
+  Ray_Superellipsoid_Tests,
+  Ray_Superellipsoid_Tests_Succeeded,
   Ray_Sor_Tests,
   Ray_Sor_Tests_Succeeded,
   Sor_Bound_Tests,
   Sor_Bound_Tests_Succeeded,
-  Ray_Sphere_Tests,
-  Ray_Sphere_Tests_Succeeded,
   Ray_Torus_Tests,
   Ray_Torus_Tests_Succeeded,
   Torus_Bound_Tests,
   Torus_Bound_Tests_Succeeded,
-  Ray_CSG_Intersection_Tests,
-  Ray_CSG_Intersection_Tests_Succeeded,
-  Ray_CSG_Merge_Tests,
-  Ray_CSG_Merge_Tests_Succeeded,
-  Ray_CSG_Union_Tests,
-  Ray_CSG_Union_Tests_Succeeded,
   Ray_Triangle_Tests,
   Ray_Triangle_Tests_Succeeded,
   Ray_TTF_Tests,
   Ray_TTF_Tests_Succeeded,
-  Ray_Superellipsoid_Tests,
-  Ray_Superellipsoid_Tests_Succeeded,
-  Atmosphere_Samples,
-  Atmosphere_Supersamples,
 
+  /* bounding etc */
+  Bounding_Region_Tests,
+  Bounding_Region_Tests_Succeeded,
+  Clipping_Region_Tests,
+  Clipping_Region_Tests_Succeeded,
+
+  /* isosurface and functions */
+  Ray_IsoSurface_Find_Root,
+  Ray_Function_VM_Calls,
+  Ray_Function_VM_Instruction_Est,
+
+  /* Vista and light buffer */
+  VBuffer_Tests,
+  VBuffer_Tests_Succeeded,
+  LBuffer_Tests,
+  LBuffer_Tests_Succeeded,
+
+  /* Media */
+  Media_Samples,
+  Media_Intervals,
+
+  /* Ray */
   Reflected_Rays_Traced,
   Refracted_Rays_Traced,
   Transmitted_Rays_Traced,
+  Internal_Reflected_Rays_Traced,
   Shadow_Cache_Hits,
   Shadow_Rays_Succeeded,
   Shadow_Ray_Tests,
@@ -229,14 +278,6 @@ typedef enum STATS
   totalQueueResizes,
   Polynomials_Tested,
   Roots_Eliminated,
-  VBuffer_Tests,
-  VBuffer_Tests_Succeeded,
-  LBuffer_Tests,
-  LBuffer_Tests_Succeeded,
-
-  Halo_Samples,
-  Halo_Supersamples,
-  Halo_Rays_Traced,
 
 #if defined(MEM_STATS)
   MemStat_Smallest_Alloc,
@@ -248,60 +289,49 @@ typedef enum STATS
 #endif
 #endif
 
+  /* NK phmap */
+  Number_Of_Photons_Shot,
+  Number_Of_Photons_Stored,
+  Number_Of_Global_Photons_Stored,
+  Number_Of_Media_Photons_Stored,
+  Priority_Queue_Add,
+  Priority_Queue_Remove,
+  Gather_Performed_Count,
+  Gather_Expanded_Count,
+
   /* Must be the last */
   MaxStat
 
 } Stats;
 
-
-typedef enum shelltype
- {
-   PRE_SCENE_SHL = 0,
-   PRE_FRAME_SHL,
-   POST_FRAME_SHL,
-   POST_SCENE_SHL,
-   USER_ABORT_SHL,
-   FATAL_SHL,
-   MAX_SHL /* Must be last */
- } SHELLTYPE;
-
-typedef enum shellret
+typedef struct intersection_stats_info
 {
-  IGNORE_RET = 0,
-  QUIT_RET,
-  USER_RET,
-  FATAL_RET,
-  SKIP_ONCE_RET,
-  ALL_SKIP_RET
-} SHELLRET;
-
-typedef struct shelldata
- {
-   SHELLRET Ret;
-   int Inverse;
-   char Command[POV_MAX_CMD_LENGTH];
- } SHELLDATA;
+  int povms_id;
+  Stats stat_test_id;
+  Stats stat_suc_id;
+  char *infotext;
+} INTERSECTION_STATS_INFO;
 
 typedef struct OPTIONS_STRUCT
 {
-  int File_Buffer_Size;
-  unsigned long Options;
+  unsigned int Options;
   char DisplayFormat;
   char PaletteOption;
 
   char OutputFormat;
   int OutputQuality;
+  int Output_File_Type;
   char Input_File_Name[FILE_NAME_LENGTH];
   char Output_File_Name[FILE_NAME_LENGTH];
   char Output_Path[FILE_NAME_LENGTH];
   char Output_Numbered_Name[FILE_NAME_LENGTH];
   char Scene_Name[FILE_NAME_LENGTH];
-  DBL DisplayGamma;
-  DBL GammaFactor;
+  COLC DisplayGamma;
+  COLC GammaFactor;
 
-  unsigned long Quality_Flags;
+  unsigned int Quality_Flags;
 
-  long AntialiasDepth;
+  int AntialiasDepth;
   DBL Antialias_Threshold;
 
   DBL JitterScale;
@@ -318,9 +348,9 @@ typedef struct OPTIONS_STRUCT
   DBL First_Line_Percent, Last_Line_Percent;
 
   /* Parse */
-  DBL Language_Version;
+  int Language_Version;
 
-  unsigned Use_Slabs;
+  bool Use_Slabs;
   long BBox_Threshold;
 
   int Quality;
@@ -349,77 +379,107 @@ typedef struct OPTIONS_STRUCT
   int Radiosity_File_KeepAlways;
   int Radiosity_Preview_Done;  /* used in cache file processing */
 
+  /* NK rad */
+  DBL Real_Radiosity_Error_Bound;
+  DBL Maximum_Sample_Brightness;
+  DBL Radiosity_ADC_Bailout;
+  int Radiosity_Use_Normal;
+  int Radiosity_Use_Media;
+  char *Radiosity_Load_File_Name;
+  char *Radiosity_Save_File_Name;
+  int Radiosity_Add_On_Final_Trace;
+  bool Radiosity_Enabled;
+  DBL radPretraceStart;
+  DBL radPretraceEnd;
 
-  int histogram_x, histogram_y, histogram_on;
+  int histogram_x, histogram_y;
+  bool histogram_on;
   Histogram_Types histogram_type;
+  int histogram_file_type;
   char Histogram_File_Name[FILE_NAME_LENGTH];
 
-  SHELLDATA *Shellouts;
+  SHELLDATA Shellouts[MAX_SHL];
 
   char Ini_Output_File_Name[FILE_NAME_LENGTH];
 
+  char Header_File_Name[FILE_NAME_LENGTH];
+
   int Tracing_Method;
   int Do_Stats;
+
+  unsigned long Preview_RefCon;
+
+  int Warning_Level;
+
+  int String_Encoding;
+
+  int Noise_Generator;
+
+  POVMSAttributeList Declared_Variables;
 } Opts;
 
+
 /*****************************************************************************
 * Global variables
 ******************************************************************************/
+
+extern char Actual_Output_Name[FILE_NAME_LENGTH];
+
+extern int Cooperate_Render_Flag;
+
 extern FRAME Frame;
 
 extern COUNTER stats[MaxStat];
 extern COUNTER totalstats[MaxStat];
 
 extern time_t tstart, tstop;
-extern DBL tparse, trender, tparse_total, trender_total;
+extern DBL tparse, tphoton, trender;
+extern DBL tparse_frame, tphoton_frame, trender_frame;
+extern DBL tparse_total, tphoton_total, trender_total;
 
 extern char Color_Bits;
 
 extern int Number_Of_Files;
 extern Opts opts;
 
-extern FILE *stat_file;
-extern FILE_HANDLE *Output_File_Handle;
-
-
-extern int Help_Available;
+extern OStream *stat_file;
+extern Image_File_Class *Output_File;
 
 extern int Abort_Test_Every;
 extern int Display_Started;
 extern int Stage;
 extern volatile int Stop_Flag;
-extern int pre_init_flag;
 extern int Experimental_Flag;
 
-extern int Num_Echo_Lines, Echo_Line_Length;
+extern int Num_Echo_Lines;
 extern char *Option_String_Ptr;      
+extern DBL Clock_Delta;
+
+END_POV_NAMESPACE
+
+#if(USE_LOCAL_POVMS_OUTPUT == 1)
+extern POVMSContext POVMS_Output_Context;
+#endif
+
 
 /*****************************************************************************
 * Global functions
 ******************************************************************************/
 
-#ifdef NOCMDLINE
-# ifdef ALTMAIN
-  MAIN_RETURN_TYPE alt_main PARAMS((void));
-# else
-  MAIN_RETURN_TYPE main PARAMS((void));
-# endif
-#else
-# ifdef ALTMAIN
-  MAIN_RETURN_TYPE alt_main PARAMS((int argc, char ** argv));
-# else
-  MAIN_RETURN_TYPE main PARAMS((int argc, char ** argv));
-# endif
+void povray_init();
+void povray_terminate();
+void povray_exit(int i);
+
+void povray_cooperate();
+
+#if(USE_LOCAL_POVMS_OUTPUT == 1)
+POVMSAddress povray_getoutputcontext();
 #endif
 
-int pov_stricmp PARAMS((char *s1,char *s2));
-void close_all PARAMS((void));
-void POV_Std_Split_Time PARAMS((DBL time_dif,unsigned long *hrs,unsigned long *mins,DBL *secs));
-FILE *Locate_File PARAMS((char *filename, char *mode, char *ext1, char *ext2, int err_flag));
+BEGIN_POV_NAMESPACE
 
-SHELLRET pov_shellout PARAMS((SHELLTYPE Type));
-void pre_init_povray PARAMS((void));
+void Do_Cooperate(int level);
 
-void POV_Split_Path PARAMS((char *s, char *p, char *f));
+END_POV_NAMESPACE
 
 #endif
