@@ -1,25 +1,33 @@
 /****************************************************************************
-*                   sor.h
-*
-*  This module contains all defines, typedefs, and prototypes for SOR.C.
-*
-*  from Persistence of Vision(tm) Ray Tracer
-*  Copyright 1996 Persistence of Vision Team
-*---------------------------------------------------------------------------
-*  NOTICE: This source code file is provided so that users may experiment
-*  with enhancements to POV-Ray and to port the software to platforms other
-*  than those supported by the POV-Ray Team.  There are strict rules under
-*  which you are permitted to use this file.  The rules are in the file
-*  named POVLEGAL.DOC which should be distributed with this file. If
-*  POVLEGAL.DOC is not available or for more info please contact the POV-Ray
-*  Team Coordinator by leaving a message in CompuServe's Graphics Developer's
-*  Forum.  The latest version of POV-Ray may be found there as well.
-*
-* This program is based on the popular DKB raytracer version 2.12.
-* DKBTrace was originally written by David K. Buck.
-* DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
-*
-*****************************************************************************/
+ *                  sor.h
+ *
+ * This module contains all defines, typedefs, and prototypes for SOR.CPP.
+ *
+ * from Persistence of Vision(tm) Ray Tracer version 3.6.
+ * Copyright 1991-2003 Persistence of Vision Team
+ * Copyright 2003-2004 Persistence of Vision Raytracer Pty. Ltd.
+ *---------------------------------------------------------------------------
+ * NOTICE: This source code file is provided so that users may experiment
+ * with enhancements to POV-Ray and to port the software to platforms other
+ * than those supported by the POV-Ray developers. There are strict rules
+ * regarding how you are permitted to use this file. These rules are contained
+ * in the distribution and derivative versions licenses which should have been
+ * provided with this file.
+ *
+ * These licences may be found online, linked from the end-user license
+ * agreement that is located at http://www.povray.org/povlegal.html
+ *---------------------------------------------------------------------------
+ * This program is based on the popular DKB raytracer version 2.12.
+ * DKBTrace was originally written by David K. Buck.
+ * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
+ *---------------------------------------------------------------------------
+ * $File: //depot/povray/3.6-release/source/sor.h $
+ * $Revision: #2 $
+ * $Change: 2939 $
+ * $DateTime: 2004/07/04 13:43:26 $
+ * $Author: root $
+ * $Log$
+ *****************************************************************************/
 
 
 
@@ -28,7 +36,7 @@
 
 #include "bcyl.h"
 
-
+BEGIN_POV_NAMESPACE
 
 /*****************************************************************************
 * Global preprocessor definitions
@@ -66,7 +74,6 @@ struct Sor_Spline_Struct
 struct Sor_Struct
 {
   OBJECT_FIELDS
-  TRANSFORM *Trans;
   int Number;
   SOR_SPLINE *Spline;      /* List of spline segments     */
   DBL Height1, Height2;    /* Min./Max. height            */
@@ -88,10 +95,10 @@ struct Sor_Struct
 * Global functions
 ******************************************************************************/
 
-SOR  *Create_Sor PARAMS((void));
-void Compute_Sor_BBox PARAMS((SOR *Sor));
-void Compute_Sor PARAMS((SOR *Sor, UV_VECT *P));
-
+SOR  *Create_Sor (void);
+void Compute_Sor_BBox (SOR *Sor);
+void Compute_Sor (SOR *Sor, UV_VECT *P);
 
+END_POV_NAMESPACE
 
 #endif
